@@ -1,4 +1,4 @@
-from metacity.filesystem import file as fs
+from metacity.filesystem import base as fs
 #from metacity.io.cityjson.parser import parse as parse_cj
 from metacity.io.geojson.parser import parse as parse_gj
 from metacity.io.shapefile.parser import parse as parse_shp
